Index: src/mark-compact.h |
diff --git a/src/mark-compact.h b/src/mark-compact.h |
index 6420a21fe3b0ac746706bf13605188c80e1bf83e..8bee6ab9dcab0e546d4e84f8ca75e7b1bdfeaf71 100644 |
--- a/src/mark-compact.h |
+++ b/src/mark-compact.h |
@@ -584,7 +584,7 @@ class MarkCompactCollector { |
bool was_marked_incrementally_; |
- bool collect_maps_; |
+ bool clear_map_transitions_; |
bool flush_monomorphic_ics_; |
@@ -608,12 +608,12 @@ class MarkCompactCollector { |
// |
// After: Live objects are marked and non-live objects are unmarked. |
- |
friend class RootMarkingVisitor; |
friend class MarkingVisitor; |
friend class StaticMarkingVisitor; |
friend class CodeMarkingVisitor; |
friend class SharedFunctionInfoMarkingVisitor; |
+ friend class IncrementalMarking; |
// Mark non-optimize code for functions inlined into the given optimized |
// code. This will prevent it from being flushed. |
@@ -642,8 +642,9 @@ class MarkCompactCollector { |
void ProcessNewlyMarkedObject(HeapObject* obj); |
- // Mark a Map and its DescriptorArray together, skipping transitions. |
- void MarkMapContents(Map* map); |
+ // Mark weak pointers in a Map and its DescriptorArray together, possibly |
+ // skipping transitions or back pointers. |
+ void MarkWeakMapContents(Map* map); |
void MarkAccessorPairSlot(HeapObject* accessors, int offset); |
void MarkDescriptorArray(DescriptorArray* descriptors); |